==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebColumnTemplateContextDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnTemplateContextDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnTemplateContextDescription, _super);
    function WebColumnTemplateContextDescription() {
        var _this = _super.call(this) || this;
        _this.g = null;
        _this.f = null;
        return _this;
    }
    WebColumnTemplateContextDescription.prototype.get_type = function () {
        return "WebColumnTemplateContext";
    };
    Object.defineProperty(WebColumnTemplateContextDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebColumnTemplateContextDescription.prototype, "implicit", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("Implicit");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebColumnTemplateContextDescription.prototype, "column", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Column");
        },
        enumerable: true,
        configurable: true
    });
    WebColumnTemplateContextDescription.$t = markType(WebColumnTemplateContextDescription, 'WebColumnTemplateContextDescription', Description.$);
    WebColumnTemplateContextDescription.__marshalByValue = true;
    WebColumnTemplateContextDescription.__marshalByValueAlias = "ColumnTemplateContext";
    return WebColumnTemplateContextDescription;
}(Description));
export { WebColumnTemplateContextDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebColumnTemplateContextDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnTemplateContextDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnTemplateContextDescription, _super);
    function WebColumnTemplateContextDescription() {
        var _this = _super.call(this) || this;
        _this.i = null;
        _this.h = null;
        return _this;
    }
    WebColumnTemplateContextDescription.prototype.get_type = function () {
        return "WebColumnTemplateContext";
    };
    Object.defineProperty(WebColumnTemplateContextDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnTemplateContextDescription.prototype, "implicit", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("Implicit");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnTemplateContextDescription.prototype, "column", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Column");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnTemplateContextDescription.$t = markType(WebColumnTemplateContextDescription, 'WebColumnTemplateContextDescription', Description.$);
    WebColumnTemplateContextDescription.__marshalByValue = true;
    WebColumnTemplateContextDescription.__marshalByValueAlias = "ColumnTemplateContext";
    return WebColumnTemplateContextDescription;
}(Description));
export { WebColumnTemplateContextDescription };
